@@ -14,3 +14,13 @@ class EventConfiguration(AbstractEventConfiguration):
 
     class Meta:
         db_table = 'event_configuration'
+
+class EventConfigurationShieldMail(AbstractRelationTime):
+
+
+    _type = models.IntegerField()
+    mail = models.CharField(max_length=100, null=True)
+
+    class Meta:
+        db_table = 'event_configuration_shield_mail'
+
