@@ -4,9 +4,11 @@ from rest_framework.response import Response
 
 from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perform_create
-from bluedot_rest_framework.utils.jwt_token import jwt_get_wechatid_handler,jwt_get_userid_handler
-
+from bluedot_rest_framework.utils.jwt_token import jwt_get_wechatid_handler, jwt_get_userid_handler
+from bluedot_rest_framework.wechat import OfficialAccount
+from bluedot_rest_framework.wechat.template_message import event_register_template
 
+Event = import_string('event.models')
 EventRegister = import_string('event.register.models')
 EventRegisterSerializer = import_string('event.register.serializers')
 EventRegisterConfig = import_string('event.register.config_models')
@@ -36,9 +38,9 @@ class EventRegisterView(CustomModelViewSet):
         event_id = request.query_params.get('event_id', None)
         wechat_id = jwt_get_wechatid_handler(request.auth)
         if wechat_id == 0:
-            userid=jwt_get_userid_handler(request.auth)
+            userid = jwt_get_userid_handler(request.auth)
             queryset = self.model_class.objects.filter(
-            userid=userid, event_id=event_id).first()
+                userid=userid, event_id=event_id).first()
         else:
             queryset = self.model_class.objects.filter(
                 wechat_id=wechat_id, event_id=event_id).first()
@@ -47,6 +49,31 @@ class EventRegisterView(CustomModelViewSet):
             state = queryset.state
         return Response({'state': state})
 
+    def update(self, request, *args, **kwargs):
+        data = request.data
+        partial = kwargs.pop('partial', False)
+        instance = self.get_object()
+        serializer = self.get_serializer(
+            instance, data=data, partial=partial)
+        serializer.is_valid(raise_exception=True)
+        self.perform_update(serializer)
+        if data['state'] == 1:
+            queryset = self.model_class.objects.get(pk=data['id'])
+            event_id = queryset.event_id
+            wechat_id = queryset.wechat_id
+            event_queryset = Event.objects.filter(pk=event_id).first()
+            keyword1 = event_queryset.title
+            keyword3 = str(event_queryset.start_time)
+            keyword4 = event_queryset.address_info
+            if event_queryset.event_type == 1:
+                remark = '线上活动'
+            else:
+                remark = '线下活动'
+            event_register_template(
+                wechat_id=wechat_id, event_id=event_id, keyword1=keyword1, keyword3=keyword3, keyword4=keyword4, remark=remark)
+            return Response('success')
+        return Response(serializer.data)
+
 
 class EventRegisterConfigView(CustomModelViewSet):
     model_class = EventRegisterConfig
