@@ -7,7 +7,7 @@ from bluedot_rest_framework import import_string
 class WechatLoginConsumer(WebsocketConsumer):
     def connect(self):
         self.scene_str = self.scope['url_route']['kwargs']['scene_str']
-        self.room_group_name = 'pc_login_%s' % self.scene_str
+        self.room_group_name = self.scene_str
 
         # Join room group
         async_to_sync(self.channel_layer.group_add)(
@@ -42,7 +42,7 @@ class WechatLoginConsumer(WebsocketConsumer):
 
     # Receive message from room group
 
-    def event_chat_message(self, event):
+    def wechat_login_message(self, data):
         self.send(text_data=json.dumps({
-            **event
+            **data
         }))
