@@ -78,7 +78,7 @@ class Response(APIView):
                 self.perform_text(msg_dict)
 
         elif msg.type == 'event':
-            openid =msg_dict['FromUserName']
+            openid = msg_dict['FromUserName']
             if msg_dict['Event'] == 'unsubscribe':
                 open_queryset = WeChatUserOpenid.objects.filter(
                     openid=openid).first()
@@ -93,9 +93,9 @@ class Response(APIView):
                         pk=queryset.material_id)
                     self.reply_text = queryset.content
                 else:
-                    self.perform_event(msg_dict,openid)
+                    self.perform_event(msg_dict)
 
-            if msg_dict['Event'] in ['subscribe','subscribe_scan']:
+            if msg_dict['Event'] in ['subscribe', 'subscribe_scan']:
                 openid = openid = msg_dict['FromUserName']
                 open_queryset = WeChatUserOpenid.objects.filter(
                     openid=openid).first()
