@@ -10,7 +10,7 @@ UserSerializer = import_string('user.serializers')
 
 class WeChatUserSerializer(CustomSerializer):
     profile = SerializerMethodField()
-    openid = SerializerMethodField()
+    wechat_profile = SerializerMethodField()
 
     class Meta:
         model = WeChatUser
@@ -25,7 +25,7 @@ class WeChatUserSerializer(CustomSerializer):
         else:
             return None
 
-    def get_openid(self, queryset):
+    def get_wechat_profile(self, queryset):
         queryset = WeChatUserOpenid.objects.filter(
             wechat_id=queryset.id).first()
         return {
